@@ -1,5 +1,5 @@
 package Form::Factory::Test::Action::Controls;
-our $VERSION = '0.003';
+our $VERSION = '0.004';
 
 
 use Test::Able;
@@ -30,7 +30,7 @@ test plan => 8, run_action => sub {
         value       => 'universe',
     });
 
-    is($action->content->{button}, 'Foo', 'button is Foo');
+    is($action->content->{button}, '', 'button is blank');
     is($action->content->{checkbox}, 'xyz', 'checkbox is xyz');
     is($action->content->{full_text}, "This is a test.\nTesting 1. 2. 3.", 
         'full_text is correct');
